/** @file

Copyright (c) 2022, Intel Corporation. All rights reserved.<BR>

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice, this
  list of conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution.
* Neither the name of Intel Corporation nor the names of its contributors may
  be used to endorse or promote products derived from this software without
  specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  THE POSSIBILITY OF SUCH DAMAGE.

  This file is automatically generated. Please do NOT modify !!!

**/

#ifndef __FSPMUPD_H__
#define __FSPMUPD_H__

#include <FspUpd.h>

#pragma pack(1)


#include <MemInfoHob.h>

///
/// The ChipsetInit Info structure provides the information of ME ChipsetInit CRC and BIOS ChipsetInit CRC.
///
typedef struct {
  UINT8             Revision;         ///< Chipset Init Info Revision
  UINT8             Rsvd[3];          ///< Reserved
  UINT16            MeChipInitCrc;    ///< 16 bit CRC value of MeChipInit Table
  UINT16            BiosChipInitCrc;  ///< 16 bit CRC value of PchChipInit Table
} CHIPSET_INIT_INFO;


/** Fsp M Configuration
**/
typedef struct {

/** Offset 0x0040 - Platform Reserved Memory Size
  The minimum platform memory size required to pass control into DXE
**/
  UINT64                      PlatformMemorySize;

/** Offset 0x0048 - SPD Data Length
  Length of SPD Data
  0x100:256 Bytes, 0x200:512 Bytes, 0x400:1024 Bytes
**/
  UINT16                      MemorySpdDataLen;

/** Offset 0x004A - Reserved
**/
  UINT8                       Reserved0;

/** Offset 0x004B - Enable/Disable CrashLog Device 10
  Enable(Default): Enable CPU CrashLog Device 10, Disable: Disable CPU CrashLog
  $EN_DIS
**/
  UINT8                       CpuCrashLogDevice;

/** Offset 0x004C - Memory SPD Pointer Controller 0 Channel 0 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr000;

/** Offset 0x0050 - Memory SPD Pointer Controller 0 Channel 0 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr001;

/** Offset 0x0054 - Memory SPD Pointer Controller 0 Channel 1 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr010;

/** Offset 0x0058 - Memory SPD Pointer Controller 0 Channel 1 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr011;

/** Offset 0x005C - Memory SPD Pointer Controller 0 Channel 2 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr020;

/** Offset 0x0060 - Memory SPD Pointer Controller 0 Channel 2 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr021;

/** Offset 0x0064 - Memory SPD Pointer Controller 0 Channel 3 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr030;

/** Offset 0x0068 - Memory SPD Pointer Controller 0 Channel 3 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr031;

/** Offset 0x006C - Memory SPD Pointer Controller 1 Channel 0 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr100;

/** Offset 0x0070 - Memory SPD Pointer Controller 1 Channel 0 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr101;

/** Offset 0x0074 - Memory SPD Pointer Controller 1 Channel 1 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr110;

/** Offset 0x0078 - Memory SPD Pointer Controller 1 Channel 1 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr111;

/** Offset 0x007C - Memory SPD Pointer Controller 1 Channel 2 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr120;

/** Offset 0x0080 - Memory SPD Pointer Controller 1 Channel 2 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr121;

/** Offset 0x0084 - Memory SPD Pointer Controller 1 Channel 3 Dimm 0
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr130;

/** Offset 0x0088 - Memory SPD Pointer Controller 1 Channel 3 Dimm 1
  Pointer to SPD data, will be used only when SpdAddressTable SPD Address are marked as 00
**/
  UINT32                      MemorySpdPtr131;

/** Offset 0x008C - RcompResistor settings
  Indicates  RcompResistor settings: Board-dependent
**/
  UINT16                      RcompResistor;

/** Offset 0x008E - RcompTarget settings
  RcompTarget settings: board-dependent
**/
  UINT16                      RcompTarget[5];

/** Offset 0x0098 - Dqs Map CPU to DRAM MC 0 CH 0
  Set Dqs mapping relationship between CPU and DRAM, Channel 0: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc0Ch0[2];

/** Offset 0x009A - Dqs Map CPU to DRAM MC 0 CH 1
  Set Dqs mapping relationship between CPU and DRAM, Channel 1: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc0Ch1[2];

/** Offset 0x009C - Dqs Map CPU to DRAM MC 0 CH 2
  Set Dqs mapping relationship between CPU and DRAM, Channel 2: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc0Ch2[2];

/** Offset 0x009E - Dqs Map CPU to DRAM MC 0 CH 3
  Set Dqs mapping relationship between CPU and DRAM, Channel 3: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc0Ch3[2];

/** Offset 0x00A0 - Dqs Map CPU to DRAM MC 1 CH 0
  Set Dqs mapping relationship between CPU and DRAM, Channel 0: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc1Ch0[2];

/** Offset 0x00A2 - Dqs Map CPU to DRAM MC 1 CH 1
  Set Dqs mapping relationship between CPU and DRAM, Channel 1: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc1Ch1[2];

/** Offset 0x00A4 - Dqs Map CPU to DRAM MC 1 CH 2
  Set Dqs mapping relationship between CPU and DRAM, Channel 2: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc1Ch2[2];

/** Offset 0x00A6 - Dqs Map CPU to DRAM MC 1 CH 3
  Set Dqs mapping relationship between CPU and DRAM, Channel 3: board-dependent
**/
  UINT8                       DqsMapCpu2DramMc1Ch3[2];

/** Offset 0x00A8 - Dq Map CPU to DRAM MC 0 CH 0
  Set Dq mapping relationship between CPU and DRAM, Channel 0: board-dependent
**/
  UINT8                       DqMapCpu2DramMc0Ch0[16];

/** Offset 0x00B8 - Dq Map CPU to DRAM MC 0 CH 1
  Set Dq mapping relationship between CPU and DRAM, Channel 1: board-dependent
**/
  UINT8                       DqMapCpu2DramMc0Ch1[16];

/** Offset 0x00C8 - Dq Map CPU to DRAM MC 0 CH 2
  Set Dq mapping relationship between CPU and DRAM, Channel 2: board-dependent
**/
  UINT8                       DqMapCpu2DramMc0Ch2[16];

/** Offset 0x00D8 - Dq Map CPU to DRAM MC 0 CH 3
  Set Dq mapping relationship between CPU and DRAM, Channel 3: board-dependent
**/
  UINT8                       DqMapCpu2DramMc0Ch3[16];

/** Offset 0x00E8 - Dq Map CPU to DRAM MC 1 CH 0
  Set Dq mapping relationship between CPU and DRAM, Channel 0: board-dependent
**/
  UINT8                       DqMapCpu2DramMc1Ch0[16];

/** Offset 0x00F8 - Dq Map CPU to DRAM MC 1 CH 1
  Set Dq mapping relationship between CPU and DRAM, Channel 1: board-dependent
**/
  UINT8                       DqMapCpu2DramMc1Ch1[16];

/** Offset 0x0108 - Dq Map CPU to DRAM MC 1 CH 2
  Set Dq mapping relationship between CPU and DRAM, Channel 2: board-dependent
**/
  UINT8                       DqMapCpu2DramMc1Ch2[16];

/** Offset 0x0118 - Dq Map CPU to DRAM MC 1 CH 3
  Set Dq mapping relationship between CPU and DRAM, Channel 3: board-dependent
**/
  UINT8                       DqMapCpu2DramMc1Ch3[16];

/** Offset 0x0128 - Dqs Pins Interleaved Setting
  Indicates DqPinsInterleaved setting: board-dependent
  $EN_DIS
**/
  UINT8                       DqPinsInterleaved;

/** Offset 0x0129 - Reserved
**/
  UINT8                       Reserved1;

/** Offset 0x012A - Reserved
**/
  UINT8                       Reserved2;

/** Offset 0x012B - Reserved
**/
  UINT8                       Reserved3;

/** Offset 0x012C - Reserved
**/
  UINT8                       Reserved4;

/** Offset 0x012D - Reserved
**/
  UINT8                       Reserved5[3];

/** Offset 0x0130 - Tseg Size
  Size of SMRAM memory reserved. 0x400000 for Release build and 0x1000000 for Debug build
  0x0400000:4MB, 0x01000000:16MB
**/
  UINT32                      TsegSize;

/** Offset 0x0134 - Reserved
**/
  UINT16                      Reserved6;

/** Offset 0x0136 - Reserved
**/
  UINT8                       Reserved7;

/** Offset 0x0137 - Enable SMBus
  Enable/disable SMBus controller.
  $EN_DIS
**/
  UINT8                       SmbusEnable;

/** Offset 0x0138 - Spd Address Tabl
  Specify SPD Address table for CH0D0/CH0D1/CH1D0&CH1D1. MemorySpdPtr will be used
  if SPD Address is 00
**/
  UINT8                       SpdAddressTable[16];

/** Offset 0x0148 - Platform Debug Consent
  Enabled(All Probes+TraceHub) supports all probes with TraceHub enabled and blocks
  s0ix\n
  \n
  Enabled(Low Power) does not support DCI OOB 4-wire and Tracehub is powergated by
  default, s0ix is viable\n
  \n
  Manual:user needs to configure Advanced Debug Settings manually, aimed at advanced users
  0:Disabled, 2:Enabled (All Probes+TraceHub), 6:Enable (Low Power), 7:Manual
**/
  UINT8                       PlatformDebugConsent;

/** Offset 0x0149 - Reserved
**/
  UINT8                       Reserved8;

/** Offset 0x014A - Reserved
**/
  UINT8                       Reserved9;

/** Offset 0x014B - Reserved
**/
  UINT8                       Reserved10;

/** Offset 0x014C - Reserved
**/
  UINT8                       Reserved11;

/** Offset 0x014D - Reserved
**/
  UINT8                       Reserved12;

/** Offset 0x014E - Reserved
**/
  UINT16                      Reserved13;

/** Offset 0x0150 - Reserved
**/
  UINT16                      Reserved14;

/** Offset 0x0152 - Reserved
**/
  UINT8                       Reserved15;

/** Offset 0x0153 - Reserved
**/
  UINT8                       Reserved16;

/** Offset 0x0154 - Reserved
**/
  UINT16                      Reserved17;

/** Offset 0x0156 - Reserved
**/
  UINT16                      Reserved18;

/** Offset 0x0158 - Reserved
**/
  UINT8                       Reserved19;

/** Offset 0x0159 - Reserved
**/
  UINT8                       Reserved20;

/** Offset 0x015A - Reserved
**/
  UINT8                       Reserved21;

/** Offset 0x015B - Reserved
**/
  UINT8                       Reserved22;

/** Offset 0x015C - Reserved
**/
  UINT8                       Reserved23[2];

/** Offset 0x015E - State of X2APIC_OPT_OUT bit in the DMAR table
  0=Disable/Clear, 1=Enable/Set
  $EN_DIS
**/
  UINT8                       X2ApicOptOut;

/** Offset 0x015F - Reserved
**/
  UINT8                       Reserved24;

/** Offset 0x0160 - Base addresses for VT-d function MMIO access
  Base addresses for VT-d MMIO access per VT-d engine
**/
  UINT32                      VtdBaseAddress[9];

/** Offset 0x0184 - Disable VT-d
  0=Enable/FALSE(VT-d enabled), 1=Disable/TRUE (VT-d disabled)
  $EN_DIS
**/
  UINT8                       VtdDisable;

/** Offset 0x0185 - Reserved
**/
  UINT8                       Reserved25;

/** Offset 0x0186 - Reserved
**/
  UINT8                       Reserved26;

/** Offset 0x0187 - Internal Graphics Pre-allocated Memory
  Size of memory preallocated for internal graphics.
  0x00:0MB, 0x01:32MB, 0x02:64MB, 0x03:96MB, 0x04:128MB, 0xF0:4MB, 0xF1:8MB, 0xF2:12MB,
  0xF3:16MB, 0xF4:20MB, 0xF5:24MB, 0xF6:28MB, 0xF7:32MB, 0xF8:36MB, 0xF9:40MB, 0xFA:44MB,
  0xFB:48MB, 0xFC:52MB, 0xFD:56MB, 0xFE:60MB
**/
  UINT8                       IgdDvmt50PreAlloc;

/** Offset 0x0188 - Internal Graphics
  Enable/disable internal graphics.
  $EN_DIS
**/
  UINT8                       InternalGfx;

/** Offset 0x0189 - Board Type
  MrcBoardType, Options are 0=Mobile/Mobile Halo, 1=Desktop/DT Halo, 5=ULT/ULX/Mobile
  Halo, 7=UP Server
  0:Mobile/Mobile Halo, 1:Desktop/DT Halo, 5:ULT/ULX/Mobile Halo, 7:UP Server
**/
  UINT8                       UserBd;

/** Offset 0x018A - Reserved
**/
  UINT8                       Reserved27;

/** Offset 0x018B - Reserved
**/
  UINT8                       Reserved28;

/** Offset 0x018C - DDR Frequency Limit
  Maximum Memory Frequency Selections in Mhz. Options are 1067, 1333, 1600, 1867,
  2133, 2400, 2667, 2933 and 0 for Auto.
  1067:1067, 1333:1333, 1600:1600, 1867:1867, 2133:2133, 2400:2400, 2667:2667, 2933:2933, 0:Auto
**/
  UINT16                      DdrFreqLimit;

/** Offset 0x018E - SAGV
  System Agent dynamic frequency support.
  0:Disabled, 1:Enabled
**/
  UINT8                       SaGv;

/** Offset 0x018F - Reserved
**/
  UINT8                       Reserved29;

/** Offset 0x0190 - Reserved
**/
  UINT8                       Reserved30;

/** Offset 0x0191 - Reserved
**/
  UINT8                       Reserved31;

/** Offset 0x0192 - Controller 0 Channel 0 DIMM Control
  Enable / Disable DIMMs on Controller 0 Channel 0
  $EN_DIS
**/
  UINT8                       DisableMc0Ch0;

/** Offset 0x0193 - Controller 0 Channel 1 DIMM Control
  Enable / Disable DIMMs on Controller 0 Channel 1
  $EN_DIS
**/
  UINT8                       DisableMc0Ch1;

/** Offset 0x0194 - Controller 0 Channel 2 DIMM Control
  Enable / Disable DIMMs on Controller 0 Channel 2
  $EN_DIS
**/
  UINT8                       DisableMc0Ch2;

/** Offset 0x0195 - Controller 0 Channel 3 DIMM Control
  Enable / Disable DIMMs on Controller 0 Channel 3
  $EN_DIS
**/
  UINT8                       DisableMc0Ch3;

/** Offset 0x0196 - Controller 1 Channel 0 DIMM Control
  Enable / Disable DIMMs on Controller 1 Channel 0
  $EN_DIS
**/
  UINT8                       DisableMc1Ch0;

/** Offset 0x0197 - Controller 1 Channel 1 DIMM Control
  Enable / Disable DIMMs on Controller 1 Channel 1
  $EN_DIS
**/
  UINT8                       DisableMc1Ch1;

/** Offset 0x0198 - Controller 1 Channel 2 DIMM Control
  Enable / Disable DIMMs on Controller 1 Channel 2
  $EN_DIS
**/
  UINT8                       DisableMc1Ch2;

/** Offset 0x0199 - Controller 1 Channel 3 DIMM Control
  Enable / Disable DIMMs on Controller 1 Channel 3
  $EN_DIS
**/
  UINT8                       DisableMc1Ch3;

/** Offset 0x019A - Reserved
**/
  UINT8                       Reserved32;

/** Offset 0x019B - Reserved
**/
  UINT8                       Reserved33;

/** Offset 0x019C - Reserved
**/
  UINT8                       Reserved34;

/** Offset 0x019D - Reserved
**/
  UINT8                       Reserved35;

/** Offset 0x019E - Memory Reference Clock
  100MHz, 133MHz.
  0:133MHz, 1:100MHz
**/
  UINT8                       RefClk;

/** Offset 0x019F - Reserved
**/
  UINT8                       Reserved36;

/** Offset 0x01A0 - Reserved
**/
  UINT16                      Reserved37;

/** Offset 0x01A2 - Reserved
**/
  UINT16                      Reserved38;

/** Offset 0x01A4 - Reserved
**/
  UINT16                      Reserved39;

/** Offset 0x01A6 - Reserved
**/
  UINT16                      Reserved40;

/** Offset 0x01A8 - Reserved
**/
  UINT8                       Reserved41;

/** Offset 0x01A9 - Reserved
**/
  UINT8                       Reserved42;

/** Offset 0x01AA - Reserved
**/
  UINT16                      Reserved43;

/** Offset 0x01AC - Reserved
**/
  UINT16                      Reserved44;

/** Offset 0x01AE - Reserved
**/
  UINT8                       Reserved45;

/** Offset 0x01AF - Reserved
**/
  UINT8                       Reserved46;

/** Offset 0x01B0 - Reserved
**/
  UINT16                      Reserved47;

/** Offset 0x01B2 - Reserved
**/
  UINT16                      Reserved48;

/** Offset 0x01B4 - Reserved
**/
  UINT8                       Reserved49;

/** Offset 0x01B5 - Reserved
**/
  UINT8                       Reserved50;

/** Offset 0x01B6 - Reserved
**/
  UINT8                       Reserved51;

/** Offset 0x01B7 - Reserved
**/
  UINT8                       Reserved52;

/** Offset 0x01B8 - Reserved
**/
  UINT16                      Reserved53;

/** Offset 0x01BA - Reserved
**/
  UINT16                      Reserved54;

/** Offset 0x01BC - Reserved
**/
  UINT16                      Reserved55;

/** Offset 0x01BE - Reserved
**/
  UINT8                       Reserved56;

/** Offset 0x01BF - Reserved
**/
  UINT8                       Reserved57;

/** Offset 0x01C0 - Reserved
**/
  UINT8                       Reserved58;

/** Offset 0x01C1 - Reserved
**/
  UINT8                       Reserved59;

/** Offset 0x01C2 - Reserved
**/
  UINT8                       Reserved60;

/** Offset 0x01C3 - Reserved
**/
  UINT8                       Reserved61;

/** Offset 0x01C4 - Enable Intel HD Audio (Azalia)
  0: Disable, 1: Enable (Default) Azalia controller
  $EN_DIS
**/
  UINT8                       PchHdaEnable;

/** Offset 0x01C5 - Enable PCH ISH Controller
  0: Disable, 1: Enable (Default) ISH Controller
  $EN_DIS
**/
  UINT8                       PchIshEnable;

/** Offset 0x01C6 - Reserved
**/
  UINT8                       Reserved62[4];

/** Offset 0x01CA - Reserved
**/
  UINT16                      Reserved63[4];

/** Offset 0x01D2 - Reserved
**/
  UINT8                       Reserved64;

/** Offset 0x01D3 - Reserved
**/
  UINT8                       Reserved65;

/** Offset 0x01D4 - Reserved
**/
  UINT8                       Reserved66;

/** Offset 0x01D5 - Reserved
**/
  UINT8                       Reserved67;

/** Offset 0x01D6 - Reserved
**/
  UINT16                      Reserved68;

/** Offset 0x01D8 - Reserved
**/
  UINT8                       Reserved69;

/** Offset 0x01D9 - Reserved
**/
  UINT8                       Reserved70[3];

/** Offset 0x01DC - Reserved
**/
  UINT32                      Reserved71;

/** Offset 0x01E0 - Reserved
**/
  UINT32                      Reserved72;

/** Offset 0x01E4 - Reserved
**/
  UINT8                       Reserved73;

/** Offset 0x01E5 - Reserved
**/
  UINT8                       Reserved74;

/** Offset 0x01E6 - Reserved
**/
  UINT8                       Reserved75;

/** Offset 0x01E7 - Reserved
**/
  UINT8                       Reserved76;

/** Offset 0x01E8 - Reserved
**/
  UINT16                      Reserved77;

/** Offset 0x01EA - Reserved
**/
  UINT16                      Reserved78;

/** Offset 0x01EC - Reserved
**/
  UINT16                      Reserved79;

/** Offset 0x01EE - Reserved
**/
  UINT16                      Reserved80;

/** Offset 0x01F0 - Reserved
**/
  UINT8                       Reserved81;

/** Offset 0x01F1 - Reserved
**/
  UINT8                       Reserved82;

/** Offset 0x01F2 - Reserved
**/
  UINT8                       Reserved83;

/** Offset 0x01F3 - Enable/Disable SA IPU
  Enable(Default): Enable SA IPU, Disable: Disable SA IPU
  $EN_DIS
**/
  UINT8                       SaIpuEnable;

/** Offset 0x01F4 - IMGU CLKOUT Configuration
  The configuration of IMGU CLKOUT, 0: Disable;<b>1: Enable</b>.
  $EN_DIS
**/
  UINT8                       ImguClkOutEn[6];

/** Offset 0x01FA - Program GPIOs for LFP on DDI port-A device
  0=Disabled,1(Default)=eDP, 2=MIPI DSI
  0:Disabled, 1:eDP, 2:MIPI DSI
**/
  UINT8                       DdiPortAConfig;

/** Offset 0x01FB - Program GPIOs for LFP on DDI port-B device
  0(Default)=Disabled,1=eDP, 2=MIPI DSI
  0:Disabled, 1:eDP, 2:MIPI DSI
**/
  UINT8                       DdiPortBConfig;

/** Offset 0x01FC - Enable or disable HPD of DDI port A
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPortAHpd;

/** Offset 0x01FD - Enable or disable HPD of DDI port B
  0=Disable, 1(Default)=Enable
  $EN_DIS
**/
  UINT8                       DdiPortBHpd;

/** Offset 0x01FE - Enable or disable HPD of DDI port C
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPortCHpd;

/** Offset 0x01FF - Enable or disable HPD of DDI port 1
  0=Disable, 1(Default)=Enable
  $EN_DIS
**/
  UINT8                       DdiPort1Hpd;

/** Offset 0x0200 - Enable or disable HPD of DDI port 2
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort2Hpd;

/** Offset 0x0201 - Enable or disable HPD of DDI port 3
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort3Hpd;

/** Offset 0x0202 - Enable or disable HPD of DDI port 4
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort4Hpd;

/** Offset 0x0203 - Enable or disable DDC of DDI port A
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPortADdc;

/** Offset 0x0204 - Enable or disable DDC of DDI port B
  0=Disable, 1(Default)=Enable
  $EN_DIS
**/
  UINT8                       DdiPortBDdc;

/** Offset 0x0205 - Enable or disable DDC of DDI port C
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPortCDdc;

/** Offset 0x0206 - Enable DDC setting of DDI Port 1
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort1Ddc;

/** Offset 0x0207 - Enable DDC setting of DDI Port 2
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort2Ddc;

/** Offset 0x0208 - Enable DDC setting of DDI Port 3
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort3Ddc;

/** Offset 0x0209 - Enable DDC setting of DDI Port 4
  0(Default)=Disable, 1=Enable
  $EN_DIS
**/
  UINT8                       DdiPort4Ddc;

/** Offset 0x020A - Reserved
**/
  UINT8                       Reserved84[6];

/** Offset 0x0210 - Reserved
**/
  UINT64                      Reserved85;

/** Offset 0x0218 - Reserved
**/
  UINT16                      Reserved86;

/** Offset 0x021A - Reserved
**/
  UINT8                       Reserved87;

/** Offset 0x021B - Reserved
**/
  UINT8                       Reserved88;

/** Offset 0x021C - Reserved
**/
  UINT8                       Reserved89;

/** Offset 0x021D - Reserved
**/
  UINT8                       Reserved90[113];

/** Offset 0x028E - Reserved
**/
  UINT8                       Reserved91;

/** Offset 0x028F - Reserved
**/
  UINT8                       Reserved92;

/** Offset 0x0290 - Reserved
**/
  UINT8                       Reserved93;

/** Offset 0x0291 - Reserved
**/
  UINT8                       Reserved94;

/** Offset 0x0292 - DMI Gen3 Root port preset values per lane
  Used for programming DMI Gen3 preset values per lane. Range: 0-9, 4 is default for each lane
**/
  UINT8                       DmiGen3RootPortPreset[8];

/** Offset 0x029A - Reserved
**/
  UINT8                       Reserved95[8];

/** Offset 0x02A2 - Reserved
**/
  UINT8                       Reserved96[8];

/** Offset 0x02AA - Reserved
**/
  UINT8                       Reserved97;

/** Offset 0x02AB - Reserved
**/
  UINT8                       Reserved98;

/** Offset 0x02AC - Reserved
**/
  UINT8                       Reserved99;

/** Offset 0x02AD - Reserved
**/
  UINT8                       Reserved100;

/** Offset 0x02AE - Reserved
**/
  UINT8                       Reserved101;

/** Offset 0x02AF - Reserved
**/
  UINT8                       Reserved102;

/** Offset 0x02B0 - Reserved
**/
  UINT8                       Reserved103[8];

/** Offset 0x02B8 - Reserved
**/
  UINT8                       Reserved104[8];

/** Offset 0x02C0 - Reserved
**/
  UINT8                       Reserved105[8];

/** Offset 0x02C8 - Reserved
**/
  UINT8                       Reserved106[8];

/** Offset 0x02D0 - Reserved
**/
  UINT8                       Reserved107;

/** Offset 0x02D1 - Reserved
**/
  UINT8                       Reserved108[8];

/** Offset 0x02D9 - Reserved
**/
  UINT8                       Reserved109[8];

/** Offset 0x02E1 - Reserved
**/
  UINT8                       Reserved110;

/** Offset 0x02E2 - Reserved
**/
  UINT8                       Reserved111[8];

/** Offset 0x02EA - Reserved
**/
  UINT8                       Reserved112[8];

/** Offset 0x02F2 - Reserved
**/
  UINT8                       Reserved113[8];

/** Offset 0x02FA - Reserved
**/
  UINT8                       Reserved114[8];

/** Offset 0x0302 - Reserved
**/
  UINT8                       Reserved115;

/** Offset 0x0303 - Reserved
**/
  UINT8                       Reserved116;

/** Offset 0x0304 - Reserved
**/
  UINT8                       Reserved117;

/** Offset 0x0305 - Reserved
**/
  UINT8                       Reserved118[8];

/** Offset 0x030D - Reserved
**/
  UINT8                       Reserved119;

/** Offset 0x030E - Reserved
**/
  UINT8                       Reserved120;

/** Offset 0x030F - Reserved
**/
  UINT8                       Reserved121[8];

/** Offset 0x0317 - Reserved
**/
  UINT8                       Reserved122[8];

/** Offset 0x031F - Reserved
**/
  UINT8                       Reserved123;

/** Offset 0x0320 - Reserved
**/
  UINT8                       Reserved124[8];

/** Offset 0x0328 - Reserved
**/
  UINT8                       Reserved125;

/** Offset 0x0329 - Reserved
**/
  UINT8                       Reserved126[3];

/** Offset 0x032C - Reserved
**/
  UINT32                      Reserved127;

/** Offset 0x0330 - Reserved
**/
  UINT32                      Reserved128;

/** Offset 0x0334 - Reserved
**/
  UINT32                      Reserved129;

/** Offset 0x0338 - Reserved
**/
  UINT32                      Reserved130;

/** Offset 0x033C - Reserved
**/
  UINT16                      Reserved131;

/** Offset 0x033E - Reserved
**/
  UINT16                      Reserved132;

/** Offset 0x0340 - Reserved
**/
  UINT32                      Reserved133;

/** Offset 0x0344 - Reserved
**/
  UINT32                      Reserved134;

/** Offset 0x0348 - Reserved
**/
  UINT32                      Reserved135;

/** Offset 0x034C - Reserved
**/
  UINT32                      Reserved136;

/** Offset 0x0350 - Reserved
**/
  UINT8                       Reserved137;

/** Offset 0x0351 - Reserved
**/
  UINT8                       Reserved138;

/** Offset 0x0352 - Reserved
**/
  UINT8                       Reserved139;

/** Offset 0x0353 - Reserved
**/
  UINT8                       Reserved140;

/** Offset 0x0354 - Reserved
**/
  UINT8                       Reserved141;

/** Offset 0x0355 - Reserved
**/
  UINT8                       Reserved142;

/** Offset 0x0356 - Reserved
**/
  UINT8                       Reserved143;

/** Offset 0x0357 - Hyper Threading Enable/Disable
  Enable or Disable Hyper-Threading Technology. 0: Disable; <b>1: Enable</b>
  $EN_DIS
**/
  UINT8                       HyperThreading;

/** Offset 0x0358 - Reserved
**/
  UINT8                       Reserved144;

/** Offset 0x0359 - CPU ratio value
  This value must be between Max Efficiency Ratio (LFM) and Maximum non-turbo ratio
  set by Hardware (HFM). Valid Range 0 to 63.
**/
  UINT8                       CpuRatio;

/** Offset 0x035A - Reserved
**/
  UINT8                       Reserved145;

/** Offset 0x035B - Reserved
**/
  UINT8                       Reserved146;

/** Offset 0x035C - Processor Early Power On Configuration FCLK setting
  FCLK frequency can take values of 400MHz, 800MHz and 1GHz. <b>0: 800 MHz (ULT/ULX)</b>.
  <b>1: 1 GHz (DT/Halo)</b>. Not supported on ULT/ULX.- 2: 400 MHz. - 3: Reserved
  0:800 MHz, 1: 1 GHz, 2: 400 MHz, 3: Reserved
**/
  UINT8                       FClkFrequency;

/** Offset 0x035D - Enable or Disable VMX
  Enable or Disable VMX, When enabled, a VMM can utilize the additional hardware capabilities
  provided by Vanderpool Technology. 0: Disable; <b>1: Enable</b>.
  $EN_DIS
**/
  UINT8                       VmxEnable;

/** Offset 0x035E - Reserved
**/
  UINT8                       Reserved147;

/** Offset 0x035F - Reserved
**/
  UINT8                       Reserved148;

/** Offset 0x0360 - Reserved
**/
  UINT8                       Reserved149;

/** Offset 0x0361 - Reserved
**/
  UINT8                       Reserved150;

/** Offset 0x0362 - Reserved
**/
  UINT16                      Reserved151;

/** Offset 0x0364 - Reserved
**/
  UINT16                      Reserved152;

/** Offset 0x0366 - Reserved
**/
  UINT16                      Reserved153;

/** Offset 0x0368 - Reserved
**/
  UINT8                       Reserved154;

/** Offset 0x0369 - Reserved
**/
  UINT8                       Reserved155;

/** Offset 0x036A - Reserved
**/
  UINT8                       Reserved156;

/** Offset 0x036B - Reserved
**/
  UINT8                       Reserved157;

/** Offset 0x036C - Reserved
**/
  UINT16                      Reserved158;

/** Offset 0x036E - Reserved
**/
  UINT16                      Reserved159;

/** Offset 0x0370 - Reserved
**/
  UINT16                      Reserved160;

/** Offset 0x0372 - Enable or Disable TME
  Configure Total Memory Encryption (TME) to protect DRAM data from physical attacks.
  <b>0: Disable</b>; 1: Enable.
  $EN_DIS
**/
  UINT8                       TmeEnable;

/** Offset 0x0373 - Enable CPU CrashLog
  Enable or Disable CPU CrashLog; 0: Disable; <b>1: Enable</b>.
  $EN_DIS
**/
  UINT8                       CpuCrashLogEnable;

/** Offset 0x0374 - Reserved
**/
  UINT8                       Reserved161;

/** Offset 0x0375 - Reserved
**/
  UINT8                       Reserved162;

/** Offset 0x0376 - Reserved
**/
  UINT8                       Reserved163;

/** Offset 0x0377 - Reserved
**/
  UINT8                       Reserved164[1];

/** Offset 0x0378 - Reserved
**/
  UINT16                      Reserved165[4];

/** Offset 0x0380 - Reserved
**/
  UINT8                       Reserved166[4];

/** Offset 0x0384 - Reserved
**/
  UINT8                       Reserved167[4];

/** Offset 0x0388 - Reserved
**/
  UINT16                      Reserved168[4];

/** Offset 0x0390 - Reserved
**/
  UINT16                      Reserved169[4];

/** Offset 0x0398 - Reserved
**/
  UINT8                       Reserved170;

/** Offset 0x0399 - Reserved
**/
  UINT8                       Reserved171;

/** Offset 0x039A - Reserved
**/
  UINT16                      Reserved172[15];

/** Offset 0x03B8 - Reserved
**/
  UINT8                       Reserved173[15];

/** Offset 0x03C7 - Reserved
**/
  UINT8                       Reserved174[15];

/** Offset 0x03D6 - Reserved
**/
  UINT8                       Reserved175;

/** Offset 0x03D7 - Reserved
**/
  UINT8                       Reserved176;

/** Offset 0x03D8 - Reserved
**/
  UINT16                      Reserved177[8];

/** Offset 0x03E8 - Reserved
**/
  UINT8                       Reserved178[8];

/** Offset 0x03F0 - Reserved
**/
  UINT8                       Reserved179;

/** Offset 0x03F1 - Reserved
**/
  UINT8                       Reserved180[8];

/** Offset 0x03F9 - Reserved
**/
  UINT8                       Reserved181[1];

/** Offset 0x03FA - Reserved
**/
  UINT16                      Reserved182[8];

/** Offset 0x040A - Reserved
**/
  UINT16                      Reserved183[8];

/** Offset 0x041A - Reserved
**/
  UINT8                       Reserved184[8];

/** Offset 0x0422 - Reserved
**/
  UINT8                       Reserved185;

/** Offset 0x0423 - Reserved
**/
  UINT8                       Reserved186;

/** Offset 0x0424 - Reserved
**/
  UINT16                      Reserved187;

/** Offset 0x0426 - Reserved
**/
  UINT8                       Reserved188[4];

/** Offset 0x042A - Reserved
**/
  UINT8                       Reserved189;

/** Offset 0x042B - Reserved
**/
  UINT8                       Reserved190;

/** Offset 0x042C - Reserved
**/
  UINT8                       Reserved191;

/** Offset 0x042D - Reserved
**/
  UINT8                       Reserved192;

/** Offset 0x042E - Reserved
**/
  UINT8                       Reserved193;

/** Offset 0x042F - Reserved
**/
  UINT8                       Reserved194;

/** Offset 0x0430 - Reserved
**/
  UINT16                      Reserved195[15];

/** Offset 0x044E - Reserved
**/
  UINT8                       Reserved196[15];

/** Offset 0x045D - Reserved
**/
  UINT8                       Reserved197[15];

/** Offset 0x046C - Reserved
**/
  UINT8                       Reserved198;

/** Offset 0x046D - Reserved
**/
  UINT8                       Reserved199;

/** Offset 0x046E - Reserved
**/
  UINT8                       Reserved200;

/** Offset 0x046F - Reserved
**/
  UINT8                       Reserved201;

/** Offset 0x0470 - Reserved
**/
  UINT8                       Reserved202;

/** Offset 0x0471 - Reserved
**/
  UINT8                       Reserved203;

/** Offset 0x0472 - GPIO Override
  Gpio Override Level - FSP will not configure any GPIOs and rely on GPIO setings
  before moved to FSP. Available configurations 0: Disable; 1: Level 1 - Skips GPIO
  configuration in PEI/FSPM/FSPT phase;2: Level 2 - Reserved for future use
**/
  UINT8                       GpioOverride;

/** Offset 0x0473 - Reserved
**/
  UINT8                       Reserved204;

/** Offset 0x0474 - Reserved
**/
  UINT32                      Reserved205;

/** Offset 0x0478 - Reserved
**/
  UINT32                      Reserved206;

/** Offset 0x047C - Reserved
**/
  UINT8                       Reserved207;

/** Offset 0x047D - Reserved
**/
  UINT8                       Reserved208[3];

/** Offset 0x0480 - Reserved
**/
  UINT64                      Reserved209;

/** Offset 0x0488 - Reserved
**/
  UINT8                       Reserved210;

/** Offset 0x0489 - Reserved
**/
  UINT8                       Reserved211;

/** Offset 0x048A - Reserved
**/
  UINT16                      Reserved212;

/** Offset 0x048C - Reserved
**/
  UINT8                       Reserved213;

/** Offset 0x048D - Reserved
**/
  UINT8                       Reserved214;

/** Offset 0x048E - Reserved
**/
  UINT16                      Reserved215;

/** Offset 0x0490 - Reserved
**/
  UINT16                      Reserved216[15];

/** Offset 0x04AE - Reserved
**/
  UINT8                       Reserved217[15];

/** Offset 0x04BD - Reserved
**/
  UINT8                       Reserved218[15];

/** Offset 0x04CC - Reserved
**/
  UINT8                       Reserved219;

/** Offset 0x04CD - Reserved
**/
  UINT8                       Reserved220;

/** Offset 0x04CE - Reserved
**/
  UINT8                       Reserved221;

/** Offset 0x04CF - Reserved
**/
  UINT8                       Reserved222;

/** Offset 0x04D0 - Reserved
**/
  UINT8                       Reserved223;

/** Offset 0x04D1 - Reserved
**/
  UINT8                       Reserved224;

/** Offset 0x04D2 - Reserved
**/
  UINT8                       Reserved225[8];

/** Offset 0x04DA - Reserved
**/
  UINT8                       Reserved226[8];

/** Offset 0x04E2 - Reserved
**/
  UINT8                       Reserved227[29];

/** Offset 0x04FF - Reserved
**/
  UINT8                       Reserved228;

/** Offset 0x0500 - Reserved
**/
  UINT8                       Reserved229;

/** Offset 0x0501 - Reserved
**/
  UINT8                       Reserved230;

/** Offset 0x0502 - Reserved
**/
  UINT16                      Reserved231;

/** Offset 0x0504 - Reserved
**/
  UINT16                      Reserved232[5];

/** Offset 0x050E - Reserved
**/
  UINT16                      Reserved233[5];

/** Offset 0x0518 - Reserved
**/
  UINT16                      Reserved234[5];

/** Offset 0x0522 - Reserved
**/
  UINT16                      Reserved235[5];

/** Offset 0x052C - Reserved
**/
  UINT16                      Reserved236[5];

/** Offset 0x0536 - Reserved
**/
  UINT16                      Reserved237[5];

/** Offset 0x0540 - Reserved
**/
  UINT8                       Reserved238[5];

/** Offset 0x0545 - Reserved
**/
  UINT8                       Reserved239[5];

/** Offset 0x054A - Reserved
**/
  UINT16                      Reserved240[5];

/** Offset 0x0554 - Reserved
**/
  UINT16                      Reserved241[5];

/** Offset 0x055E - Reserved
**/
  UINT8                       Reserved242[5];

/** Offset 0x0563 - Thermal Design Current enable/disable
  Thermal Design Current enable/disable; <b>0: Disable</b>; 1: Enable. [0] for IA,
  [1] for GT, [2] for SA, [3] and [4] are Reserved.
**/
  UINT8                       TdcEnable[5];

/** Offset 0x0568 - Thermal Design Current time window
  TDC Time Window, value of IA either in milliseconds or seconds, value of GT/SA is
  in milliseconds. 1ms is default. Range of IA from 1ms to 448s, Range of GT/SA is
  1ms to 10ms, except for 9ms. 9ms has no valid encoding in the MSR definition.
**/
  UINT32                      TdcTimeWindow[5];

/** Offset 0x057C - Reserved
**/
  UINT8                       Reserved243[5];

/** Offset 0x0581 - Reserved
**/
  UINT8                       Reserved244;

/** Offset 0x0582 - Reserved
**/
  UINT16                      Reserved245;

/** Offset 0x0584 - Reserved
**/
  UINT8                       Reserved246;

/** Offset 0x0585 - Reserved
**/
  UINT8                       Reserved247;

/** Offset 0x0586 - Reserved
**/
  UINT8                       Reserved248;

/** Offset 0x0587 - Reserved
**/
  UINT8                       Reserved249;

/** Offset 0x0588 - Reserved
**/
  UINT8                       Reserved250;

/** Offset 0x0589 - Reserved
**/
  UINT8                       Reserved251[1];

/** Offset 0x058A - Reserved
**/
  UINT16                      Reserved252[5];

/** Offset 0x0594 - Reserved
**/
  UINT8                       Reserved253[5];

/** Offset 0x0599 - Reserved
**/
  UINT8                       Reserved254[1];

/** Offset 0x059A - Reserved
**/
  UINT16                      Reserved255[5];

/** Offset 0x05A4 - Reserved
**/
  UINT16                      Reserved256[5];

/** Offset 0x05AE - Reserved
**/
  UINT8                       Reserved257[5];

/** Offset 0x05B3 - Reserved
**/
  UINT8                       Reserved258[1];

/** Offset 0x05B4 - Reserved
**/
  UINT16                      Reserved259[5];

/** Offset 0x05BE - Reserved
**/
  UINT16                      Reserved260[5];

/** Offset 0x05C8 - Reserved
**/
  UINT8                       Reserved261[5];

/** Offset 0x05CD - Reserved
**/
  UINT8                       Reserved262[5];

/** Offset 0x05D2 - Reserved
**/
  UINT8                       Reserved263[2];

/** Offset 0x05D4 - Reserved
**/
  UINT32                      Reserved264[5];

/** Offset 0x05E8 - Reserved
**/
  UINT16                      Reserved265;

/** Offset 0x05EA - Reserved
**/
  UINT8                       Reserved266[5];

/** Offset 0x05EF - Reserved
**/
  UINT8                       Reserved267[5];

/** Offset 0x05F4 - Reserved
**/
  UINT16                      Reserved268[5];

/** Offset 0x05FE - Reserved
**/
  UINT16                      Reserved269[5];

/** Offset 0x0608 - Reserved
**/
  UINT8                       Reserved270[5];

/** Offset 0x060D - Reserved
**/
  UINT8                       Reserved271[5];

/** Offset 0x0612 - Reserved
**/
  UINT8                       Reserved272[5];

/** Offset 0x0617 - Reserved
**/
  UINT8                       Reserved273;

/** Offset 0x0618 - BiosGuard
  Enable/Disable. 0: Disable, Enable/Disable BIOS Guard feature, 1: enable
  $EN_DIS
**/
  UINT8                       BiosGuard;

/** Offset 0x0619
**/
  UINT8                       BiosGuardToolsInterface;

/** Offset 0x061A - Reserved
**/
  UINT8                       Reserved274;

/** Offset 0x061B - Reserved
**/
  UINT8                       Reserved275;

/** Offset 0x061C - PrmrrSize
  Enable/Disable. 0: Disable, define default value of PrmrrSize , 1: enable
**/
  UINT32                      PrmrrSize;

/** Offset 0x0620 - SinitMemorySize
  Enable/Disable. 0: Disable, define default value of SinitMemorySize , 1: enable
**/
  UINT32                      SinitMemorySize;

/** Offset 0x0624 - Reserved
**/
  UINT8                       Reserved276[4];

/** Offset 0x0628 - Reserved
**/
  UINT64                      Reserved277;

/** Offset 0x0630 - TxtHeapMemorySize
  Enable/Disable. 0: Disable, define default value of TxtHeapMemorySize , 1: enable
**/
  UINT32                      TxtHeapMemorySize;

/** Offset 0x0634 - TxtDprMemorySize
  Reserve DPR memory size (0-255) MB. 0: Disable, define default value of TxtDprMemorySize
  , 1: enable
**/
  UINT32                      TxtDprMemorySize;

/** Offset 0x0638 - Reserved
**/
  UINT32                      Reserved278;

/** Offset 0x063C - Reserved
**/
  UINT32                      Reserved279;

/** Offset 0x0640 - Reserved
**/
  UINT32                      Reserved280;

/** Offset 0x0644 - Reserved
**/
  UINT32                      Reserved281;

/** Offset 0x0648 - Reserved
**/
  UINT64                      Reserved282;

/** Offset 0x0650 - Reserved
**/
  UINT64                      Reserved283;

/** Offset 0x0658 - Reserved
**/
  UINT8                       Reserved284;

/** Offset 0x0659 - Reserved
**/
  UINT8                       Reserved285[32];

/** Offset 0x0679 - Reserved
**/
  UINT8                       Reserved286[28];

/** Offset 0x0695 - Reserved
**/
  UINT8                       Reserved287[28];

/** Offset 0x06B1 - Reserved
**/
  UINT8                       Reserved288[28];

/** Offset 0x06CD - Reserved
**/
  UINT8                       Reserved289[28];

/** Offset 0x06E9 - Reserved
**/
  UINT8                       Reserved290[28];

/** Offset 0x0705 - Reserved
**/
  UINT8                       Reserved291[28];

/** Offset 0x0721 - Reserved
**/
  UINT8                       Reserved292[28];

/** Offset 0x073D - Reserved
**/
  UINT8                       Reserved293[28];

/** Offset 0x0759 - Reserved
**/
  UINT8                       Reserved294[28];

/** Offset 0x0775 - Reserved
**/
  UINT8                       Reserved295[28];

/** Offset 0x0791 - Reserved
**/
  UINT8                       Reserved296[28];

/** Offset 0x07AD - Reserved
**/
  UINT8                       Reserved297[28];

/** Offset 0x07C9 - Reserved
**/
  UINT8                       Reserved298[28];

/** Offset 0x07E5 - Reserved
**/
  UINT8                       Reserved299[28];

/** Offset 0x0801 - Reserved
**/
  UINT8                       Reserved300[8];

/** Offset 0x0809 - Reserved
**/
  UINT8                       Reserved301[8];

/** Offset 0x0811 - Reserved
**/
  UINT8                       Reserved302[8];

/** Offset 0x0819 - Reserved
**/
  UINT8                       Reserved303[8];

/** Offset 0x0821 - Reserved
**/
  UINT8                       Reserved304[8];

/** Offset 0x0829 - Reserved
**/
  UINT8                       Reserved305[8];

/** Offset 0x0831 - Reserved
**/
  UINT8                       Reserved306[8];

/** Offset 0x0839 - Reserved
**/
  UINT8                       Reserved307[8];

/** Offset 0x0841 - Reserved
**/
  UINT8                       Reserved308[8];

/** Offset 0x0849 - Reserved
**/
  UINT8                       Reserved309[8];

/** Offset 0x0851 - Reserved
**/
  UINT8                       Reserved310[8];

/** Offset 0x0859 - Reserved
**/
  UINT8                       Reserved311[8];

/** Offset 0x0861 - Reserved
**/
  UINT8                       Reserved312[8];

/** Offset 0x0869 - Reserved
**/
  UINT8                       Reserved313[8];

/** Offset 0x0871 - Reserved
**/
  UINT8                       Reserved314[8];

/** Offset 0x0879 - Reserved
**/
  UINT8                       Reserved315[8];

/** Offset 0x0881 - Reserved
**/
  UINT8                       Reserved316[8];

/** Offset 0x0889 - Reserved
**/
  UINT8                       Reserved317[8];

/** Offset 0x0891 - Reserved
**/
  UINT8                       Reserved318;

/** Offset 0x0892 - Reserved
**/
  UINT8                       Reserved319;

/** Offset 0x0893 - Reserved
**/
  UINT8                       Reserved320;

/** Offset 0x0894 - Number of RsvdSmbusAddressTable.
  The number of elements in the RsvdSmbusAddressTable.
**/
  UINT8                       PchNumRsvdSmbusAddresses;

/** Offset 0x0895 - Reserved
**/
  UINT8                       Reserved321;

/** Offset 0x0896 - Reserved
**/
  UINT16                      Reserved322;

/** Offset 0x0898 - Reserved
**/
  UINT8                       Reserved323;

/** Offset 0x0899 - Usage type for ClkSrc
  0-23: PCH rootport, 0x70:LAN, 0x80: unspecified but in use (free running), 0xFF: not used
**/
  UINT8                       PcieClkSrcUsage[18];

/** Offset 0x08AB - Reserved
**/
  UINT8                       Reserved324[14];

/** Offset 0x08B9 - ClkReq-to-ClkSrc mapping
  Number of ClkReq signal assigned to ClkSrc
**/
  UINT8                       PcieClkSrcClkReq[18];

/** Offset 0x08CB - Reserved
**/
  UINT8                       Reserved325[14];

/** Offset 0x08D9 - Reserved
**/
  UINT8                       Reserved326[3];

/** Offset 0x08DC - Reserved
**/
  UINT32                      Reserved327[8];

/** Offset 0x08FC - Reserved
**/
  UINT32                      Reserved328;

/** Offset 0x0900 - Enable PCIE RP Mask
  Enable/disable PCIE Root Ports. 0: disable, 1: enable. One bit for each port, bit0
  for port1, bit1 for port2, and so on.
**/
  UINT32                      PcieRpEnableMask;

/** Offset 0x0904 - Reserved
**/
  UINT8                       Reserved329;

/** Offset 0x0905 - Reserved
**/
  UINT8                       Reserved330;

/** Offset 0x0906 - Enable HD Audio Link
  Enable/disable HD Audio Link. Muxed with SSP0/SSP1/SNDW1.
  $EN_DIS
**/
  UINT8                       PchHdaAudioLinkHdaEnable;

/** Offset 0x0907 - Reserved
**/
  UINT8                       Reserved331[2];

/** Offset 0x0909 - Reserved
**/
  UINT8                       Reserved332;

/** Offset 0x090A - Enable HD Audio DMIC_N Link
  Enable/disable HD Audio DMIC1 link. Muxed with SNDW3.
**/
  UINT8                       PchHdaAudioLinkDmicEnable[2];

/** Offset 0x090C - DMIC<N> ClkA Pin Muxing (N - DMIC number)
  Determines DMIC<N> ClkA Pin muxing. See  GPIO_*_MUXING_DMIC<N>_CLKA_*
**/
  UINT32                      PchHdaAudioLinkDmicClkAPinMux[2];

/** Offset 0x0914 - DMIC<N> ClkB Pin Muxing
  Determines DMIC<N> ClkA Pin muxing. See GPIO_*_MUXING_DMIC<N>_CLKB_*
**/
  UINT32                      PchHdaAudioLinkDmicClkBPinMux[2];

/** Offset 0x091C - Enable HD Audio DSP
  Enable/disable HD Audio DSP feature.
  $EN_DIS
**/
  UINT8                       PchHdaDspEnable;

/** Offset 0x091D - Reserved
**/
  UINT8                       Reserved333[3];

/** Offset 0x0920 - DMIC<N> Data Pin Muxing
  Determines DMIC<N> Data Pin muxing. See GPIO_*_MUXING_DMIC<N>_DATA_*
**/
  UINT32                      PchHdaAudioLinkDmicDataPinMux[2];

/** Offset 0x0928 - Enable HD Audio SSP0 Link
  Enable/disable HD Audio SSP_N/I2S link. Muxed with HDA. N-number 0-5
**/
  UINT8                       PchHdaAudioLinkSspEnable[6];

/** Offset 0x092E - Enable HD Audio SoundWire#N Link
  Enable/disable HD Audio SNDW#N link. Muxed with HDA.
**/
  UINT8                       PchHdaAudioLinkSndwEnable[4];

/** Offset 0x0932 - iDisp-Link Frequency
  iDisp-Link Freq (PCH_HDAUDIO_LINK_FREQUENCY enum): 4: 96MHz, 3: 48MHz.
  4: 96MHz, 3: 48MHz
**/
  UINT8                       PchHdaIDispLinkFrequency;

/** Offset 0x0933 - iDisp-Link T-mode
  iDisp-Link T-Mode (PCH_HDAUDIO_IDISP_TMODE enum): 0: 2T, 2: 4T, 3: 8T, 4: 16T
  0: 2T, 2: 4T, 3: 8T, 4: 16T
**/
  UINT8                       PchHdaIDispLinkTmode;

/** Offset 0x0934 - iDisplay Audio Codec disconnection
  0: Not disconnected, enumerable, 1: Disconnected SDI, not enumerable.
  $EN_DIS
**/
  UINT8                       PchHdaIDispCodecDisconnect;

/** Offset 0x0935 - Reserved
**/
  UINT8                       Reserved334[3];

/** Offset 0x0938 - Reserved
**/
  UINT32                      Reserved335;

/** Offset 0x093C - CNVi DDR RFI Mitigation
  Enable/Disable DDR RFI Mitigation. Default is ENABLE. 0: DISABLE, 1: ENABLE
  $EN_DIS
**/
  UINT8                       CnviDdrRfim;

/** Offset 0x093D - Reserved
**/
  UINT8                       Reserved336;

/** Offset 0x093E - Reserved
**/
  UINT8                       Reserved337;

/** Offset 0x093F - Reserved
**/
  UINT8                       Reserved338;

/** Offset 0x0940 - Reserved
**/
  UINT32                      Reserved339;

/** Offset 0x0944 - Reserved
**/
  UINT32                      Reserved340;

/** Offset 0x0948 - Debug Interfaces
  Debug Interfaces. BIT0-RAM, BIT1-UART, BIT3-USB3, BIT4-Serial IO, BIT5-TraceHub,
  BIT2 - Not used.
**/
  UINT8                       PcdDebugInterfaceFlags;

/** Offset 0x0949 - Serial Io Uart Debug Controller Number
  Select SerialIo Uart Controller for debug.
  0:SerialIoUart0, 1:SerialIoUart1, 2:SerialIoUart2
**/
  UINT8                       SerialIoUartDebugControllerNumber;

/** Offset 0x094A - Reserved
**/
  UINT8                       Reserved341;

/** Offset 0x094B - Reserved
**/
  UINT8                       Reserved342;

/** Offset 0x094C - Reserved
**/
  UINT32                      Reserved343;

/** Offset 0x0950 - Reserved
**/
  UINT8                       Reserved344;

/** Offset 0x0951 - Reserved
**/
  UINT8                       Reserved345;

/** Offset 0x0952 - Reserved
**/
  UINT8                       Reserved346;

/** Offset 0x0953 - Reserved
**/
  UINT8                       Reserved347;

/** Offset 0x0954 - Reserved
**/
  UINT32                      Reserved348;

/** Offset 0x0958 - ISA Serial Base selection
  Select ISA Serial Base address. Default is 0x3F8.
  0:0x3F8, 1:0x2F8
**/
  UINT8                       PcdIsaSerialUartBase;

/** Offset 0x0959 - Reserved
**/
  UINT8                       Reserved349;

/** Offset 0x095A - Reserved
**/
  UINT8                       Reserved350;

/** Offset 0x095B - Reserved
**/
  UINT8                       Reserved351;

/** Offset 0x095C - Reserved
**/
  UINT8                       Reserved352;

/** Offset 0x095D - TCSS Thunderbolt PCIE Root Port 0 Enable
  Set TCSS Thunderbolt PCIE Root Port 0. 0:Disabled  1:Enabled
  $EN_DIS
**/
  UINT8                       TcssItbtPcie0En;

/** Offset 0x095E - TCSS Thunderbolt PCIE Root Port 1 Enable
  Set TCSS Thunderbolt PCIE Root Port 1. 0:Disabled  1:Enabled
  $EN_DIS
**/
  UINT8                       TcssItbtPcie1En;

/** Offset 0x095F - TCSS Thunderbolt PCIE Root Port 2 Enable
  Set TCSS Thunderbolt PCIE Root Port 2. 0:Disabled  1:Enabled
  $EN_DIS
**/
  UINT8                       TcssItbtPcie2En;

/** Offset 0x0960 - TCSS Thunderbolt PCIE Root Port 3 Enable
  Set TCSS Thunderbolt PCIE Root Port 3. 0:Disabled  1:Enabled
  $EN_DIS
**/
  UINT8                       TcssItbtPcie3En;

/** Offset 0x0961 - TCSS USB HOST (xHCI) Enable
  Set TCSS XHCI. 0:Disabled  1:Enabled - Must be enabled if xDCI is enabled below
  $EN_DIS
**/
  UINT8                       TcssXhciEn;

/** Offset 0x0962 - TCSS USB DEVICE (xDCI) Enable
  Set TCSS XDCI. 0:Disabled  1:Enabled - xHCI must be enabled if xDCI is enabled
  $EN_DIS
**/
  UINT8                       TcssXdciEn;

/** Offset 0x0963 - TCSS DMA0 Enable
  Set TCSS DMA0. 0:Disabled  1:Enabled
  $EN_DIS
**/
  UINT8                       TcssDma0En;

/** Offset 0x0964 - TCSS DMA1 Enable
  Set TCSS DMA1. 0:Disabled  1:Enabled
  $EN_DIS
**/
  UINT8                       TcssDma1En;

/** Offset 0x0965 - Reserved
**/
  UINT8                       Reserved353;

/** Offset 0x0966 - Reserved
**/
  UINT8                       Reserved354;

/** Offset 0x0967 - Early Command Training
  Enables/Disable Early Command Training
  $EN_DIS
**/
  UINT8                       ECT;

/** Offset 0x0968 - Reserved
**/
  UINT8                       Reserved355;

/** Offset 0x0969 - Reserved
**/
  UINT8                       Reserved356;

/** Offset 0x096A - Reserved
**/
  UINT8                       Reserved357;

/** Offset 0x096B - Reserved
**/
  UINT8                       Reserved358;

/** Offset 0x096C - Reserved
**/
  UINT8                       Reserved359;

/** Offset 0x096D - Reserved
**/
  UINT8                       Reserved360;

/** Offset 0x096E - Reserved
**/
  UINT8                       Reserved361;

/** Offset 0x096F - Reserved
**/
  UINT8                       Reserved362;

/** Offset 0x0970 - Reserved
**/
  UINT8                       Reserved363;

/** Offset 0x0971 - Reserved
**/
  UINT8                       Reserved364;

/** Offset 0x0972 - Reserved
**/
  UINT8                       Reserved365;

/** Offset 0x0973 - Reserved
**/
  UINT8                       Reserved366;

/** Offset 0x0974 - Reserved
**/
  UINT8                       Reserved367;

/** Offset 0x0975 - Reserved
**/
  UINT8                       Reserved368;

/** Offset 0x0976 - Reserved
**/
  UINT8                       Reserved369;

/** Offset 0x0977 - Reserved
**/
  UINT8                       Reserved370;

/** Offset 0x0978 - Reserved
**/
  UINT8                       Reserved371;

/** Offset 0x0979 - Reserved
**/
  UINT8                       Reserved372;

/** Offset 0x097A - Reserved
**/
  UINT8                       Reserved373;

/** Offset 0x097B - Reserved
**/
  UINT8                       Reserved374;

/** Offset 0x097C - Reserved
**/
  UINT8                       Reserved375;

/** Offset 0x097D - Reserved
**/
  UINT8                       Reserved376;

/** Offset 0x097E - Late Command Training
  Enables/Disable Late Command Training
  $EN_DIS
**/
  UINT8                       LCT;

/** Offset 0x097F - Reserved
**/
  UINT8                       Reserved377;

/** Offset 0x0980 - Rank Margin Tool
  Enable/disable Rank Margin Tool
  $EN_DIS
**/
  UINT8                       RMT;

/** Offset 0x0981 - Reserved
**/
  UINT8                       Reserved378;

/** Offset 0x0982 - Reserved
**/
  UINT8                       Reserved379;

/** Offset 0x0983 - Reserved
**/
  UINT8                       Reserved380;

/** Offset 0x0984 - Reserved
**/
  UINT8                       Reserved381;

/** Offset 0x0985 - Reserved
**/
  UINT8                       Reserved382;

/** Offset 0x0986 - Reserved
**/
  UINT8                       Reserved383;

/** Offset 0x0987 - Reserved
**/
  UINT8                       Reserved384;

/** Offset 0x0988 - Reserved
**/
  UINT8                       Reserved385;

/** Offset 0x0989 - Reserved
**/
  UINT8                       Reserved386;

/** Offset 0x098A - Reserved
**/
  UINT8                       Reserved387;

/** Offset 0x098B - Reserved
**/
  UINT8                       Reserved388;

/** Offset 0x098C - Reserved
**/
  UINT8                       Reserved389;

/** Offset 0x098D - Reserved
**/
  UINT8                       Reserved390;

/** Offset 0x098E - Reserved
**/
  UINT8                       Reserved391;

/** Offset 0x098F - Reserved
**/
  UINT8                       Reserved392;

/** Offset 0x0990 - Reserved
**/
  UINT8                       Reserved393;

/** Offset 0x0991 - Reserved
**/
  UINT8                       Reserved394;

/** Offset 0x0992 - Reserved
**/
  UINT8                       Reserved395;

/** Offset 0x0993 - Reserved
**/
  UINT8                       Reserved396;

/** Offset 0x0994 - Reserved
**/
  UINT8                       Reserved397;

/** Offset 0x0995 - Reserved
**/
  UINT8                       Reserved398;

/** Offset 0x0996 - Reserved
**/
  UINT8                       Reserved399;

/** Offset 0x0997 - Reserved
**/
  UINT8                       Reserved400;

/** Offset 0x0998 - Reserved
**/
  UINT8                       Reserved401;

/** Offset 0x0999 - Reserved
**/
  UINT8                       Reserved402;

/** Offset 0x099A - Reserved
**/
  UINT8                       Reserved403;

/** Offset 0x099B - Reserved
**/
  UINT8                       Reserved404;

/** Offset 0x099C - Reserved
**/
  UINT8                       Reserved405;

/** Offset 0x099D - Reserved
**/
  UINT8                       Reserved406;

/** Offset 0x099E - Reserved
**/
  UINT8                       Reserved407;

/** Offset 0x099F - Reserved
**/
  UINT8                       Reserved408;

/** Offset 0x09A0 - Reserved
**/
  UINT8                       Reserved409;

/** Offset 0x09A1 - Reserved
**/
  UINT8                       Reserved410;

/** Offset 0x09A2 - Reserved
**/
  UINT8                       Reserved411;

/** Offset 0x09A3 - Reserved
**/
  UINT8                       Reserved412;

/** Offset 0x09A4 - Reserved
**/
  UINT8                       Reserved413;

/** Offset 0x09A5 - Reserved
**/
  UINT8                       Reserved414;

/** Offset 0x09A6 - Reserved
**/
  UINT8                       Reserved415;

/** Offset 0x09A7 - Reserved
**/
  UINT8                       Reserved416;

/** Offset 0x09A8 - Reserved
**/
  UINT8                       Reserved417;

/** Offset 0x09A9 - Reserved
**/
  UINT8                       Reserved418;

/** Offset 0x09AA - IbeccParity
  In-Band ECC Parity Control
  $EN_DIS
**/
  UINT8                       IbeccParity;

/** Offset 0x09AB - IbeccOperationMode
  In-Band ECC Operation Mode
  0:Protect base on address range, 1: Non-protected, 2: All protected
**/
  UINT8                       IbeccOperationMode;

/** Offset 0x09AC - IbeccProtectedRegionEnable
  In-Band ECC Protected Region Enable
  $EN_DIS
**/
  UINT8                       IbeccProtectedRegionEnable[8];

/** Offset 0x09B4 - IbeccProtectedRegionBases
  IBECC Protected Region Bases per IBECC instance
**/
  UINT16                      IbeccProtectedRegionBase[8];

/** Offset 0x09C4 - IbeccProtectedRegionMasks
  IBECC Protected Region Masks
**/
  UINT16                      IbeccProtectedRegionMask[8];

/** Offset 0x09D4 - IbeccProtectedRegionOverallBases
  IBECC Protected Region Bases based on enabled IBECC instance
**/
  UINT16                      IbeccProtectedRegionOverallBase[8];

/** Offset 0x09E4 - Reserved
**/
  UINT8                       Reserved419;

/** Offset 0x09E5 - Reserved
**/
  UINT8                       Reserved420;

/** Offset 0x09E6 - Reserved
**/
  UINT8                       Reserved421;

/** Offset 0x09E7 - Reserved
**/
  UINT8                       Reserved422;

/** Offset 0x09E8 - Reserved
**/
  UINT8                       Reserved423;

/** Offset 0x09E9 - Reserved
**/
  UINT8                       Reserved424;

/** Offset 0x09EA - Reserved
**/
  UINT8                       Reserved425;

/** Offset 0x09EB - Reserved
**/
  UINT8                       Reserved426;

/** Offset 0x09EC - Reserved
**/
  UINT8                       Reserved427;

/** Offset 0x09ED - Reserved
**/
  UINT8                       Reserved428;

/** Offset 0x09EE - Reserved
**/
  UINT8                       Reserved429;

/** Offset 0x09EF - Reserved
**/
  UINT8                       Reserved430;

/** Offset 0x09F0 - Reserved
**/
  UINT8                       Reserved431;

/** Offset 0x09F1 - Reserved
**/
  UINT8                       Reserved432;

/** Offset 0x09F2 - Reserved
**/
  UINT8                       Reserved433;

/** Offset 0x09F3 - Reserved
**/
  UINT8                       Reserved434;

/** Offset 0x09F4 - Reserved
**/
  UINT8                       Reserved435;

/** Offset 0x09F5 - Reserved
**/
  UINT8                       Reserved436;

/** Offset 0x09F6 - Ch Hash Mask
  Set the BIT(s) to be included in the XOR function. NOTE BIT mask corresponds to
  BITS [19:6] Default is 0x30CC
**/
  UINT16                      ChHashMask;

/** Offset 0x09F8 - Reserved
**/
  UINT32                      Reserved437;

/** Offset 0x09FC - Reserved
**/
  UINT16                      Reserved438;

/** Offset 0x09FE - Reserved
**/
  UINT16                      Reserved439;

/** Offset 0x0A00 - Reserved
**/
  UINT8                       Reserved440;

/** Offset 0x0A01 - Reserved
**/
  UINT8                       Reserved441;

/** Offset 0x0A02 - Reserved
**/
  UINT8                       Reserved442;

/** Offset 0x0A03 - Reserved
**/
  UINT8                       Reserved443;

/** Offset 0x0A04 - Reserved
**/
  UINT8                       Reserved444;

/** Offset 0x0A05 - Reserved
**/
  UINT8                       Reserved445;

/** Offset 0x0A06 - Reserved
**/
  UINT8                       Reserved446;

/** Offset 0x0A07 - Reserved
**/
  UINT8                       Reserved447;

/** Offset 0x0A08 - Reserved
**/
  UINT8                       Reserved448;

/** Offset 0x0A09 - Reserved
**/
  UINT8                       Reserved449;

/** Offset 0x0A0A - Reserved
**/
  UINT8                       Reserved450;

/** Offset 0x0A0B - Reserved
**/
  UINT8                       Reserved451;

/** Offset 0x0A0C - Reserved
**/
  UINT8                       Reserved452;

/** Offset 0x0A0D - Reserved
**/
  UINT8                       Reserved453;

/** Offset 0x0A0E - Reserved
**/
  UINT8                       Reserved454;

/** Offset 0x0A0F - Reserved
**/
  UINT8                       Reserved455;

/** Offset 0x0A10 - Reserved
**/
  UINT8                       Reserved456;

/** Offset 0x0A11 - Reserved
**/
  UINT8                       Reserved457;

/** Offset 0x0A12 - Reserved
**/
  UINT8                       Reserved458;

/** Offset 0x0A13 - Reserved
**/
  UINT8                       Reserved459;

/** Offset 0x0A14 - Reserved
**/
  UINT8                       Reserved460;

/** Offset 0x0A15 - Reserved
**/
  UINT8                       Reserved461;

/** Offset 0x0A16 - Reserved
**/
  UINT8                       Reserved462;

/** Offset 0x0A17 - Reserved
**/
  UINT8                       Reserved463;

/** Offset 0x0A18 - Reserved
**/
  UINT8                       Reserved464;

/** Offset 0x0A19 - Reserved
**/
  UINT8                       Reserved465;

/** Offset 0x0A1A - Reserved
**/
  UINT8                       Reserved466;

/** Offset 0x0A1B - Reserved
**/
  UINT8                       Reserved467;

/** Offset 0x0A1C - Reserved
**/
  UINT8                       Reserved468;

/** Offset 0x0A1D - Reserved
**/
  UINT8                       Reserved469;

/** Offset 0x0A1E - Reserved
**/
  UINT8                       Reserved470;

/** Offset 0x0A1F - Reserved
**/
  UINT8                       Reserved471;

/** Offset 0x0A20 - Reserved
**/
  UINT8                       Reserved472;

/** Offset 0x0A21 - Reserved
**/
  UINT8                       Reserved473;

/** Offset 0x0A22 - Reserved
**/
  UINT8                       Reserved474;

/** Offset 0x0A23 - Reserved
**/
  UINT8                       Reserved475;

/** Offset 0x0A24 - Reserved
**/
  UINT8                       Reserved476;

/** Offset 0x0A25 - Reserved
**/
  UINT8                       Reserved477;

/** Offset 0x0A26 - Reserved
**/
  UINT8                       Reserved478;

/** Offset 0x0A27 - Reserved
**/
  UINT8                       Reserved479;

/** Offset 0x0A28 - Reserved
**/
  UINT8                       Reserved480;

/** Offset 0x0A29 - Reserved
**/
  UINT8                       Reserved481;

/** Offset 0x0A2A - Reserved
**/
  UINT8                       Reserved482;

/** Offset 0x0A2B - Reserved
**/
  UINT8                       Reserved483;

/** Offset 0x0A2C - Reserved
**/
  UINT8                       Reserved484;

/** Offset 0x0A2D - Reserved
**/
  UINT8                       Reserved485;

/** Offset 0x0A2E - Reserved
**/
  UINT8                       Reserved486;

/** Offset 0x0A2F - Reserved
**/
  UINT8                       Reserved487;

/** Offset 0x0A30 - Reserved
**/
  UINT8                       Reserved488;

/** Offset 0x0A31 - Reserved
**/
  UINT8                       Reserved489;

/** Offset 0x0A32 - Reserved
**/
  UINT8                       Reserved490;

/** Offset 0x0A33 - Reserved
**/
  UINT8                       Reserved491;

/** Offset 0x0A34 - Reserved
**/
  UINT8                       Reserved492;

/** Offset 0x0A35 - Reserved
**/
  UINT8                       Reserved493;

/** Offset 0x0A36 - Reserved
**/
  UINT8                       Reserved494;

/** Offset 0x0A37 - Reserved
**/
  UINT8                       Reserved495;

/** Offset 0x0A38 - Reserved
**/
  UINT8                       Reserved496;

/** Offset 0x0A39 - PcdSerialDebugLevel
  Serial Debug Message Level. 0:Disable, 1:Error Only, 2:Error & Warnings, 3:Load,
  Error, Warnings & Info, 4:Load, Error, Warnings, Info & Event, 5:Load, Error, Warnings,
  Info & Verbose.
  0:Disable, 1:Error Only, 2:Error and Warnings, 3:Load Error Warnings and Info, 4:Load
  Error Warnings and Info & Event, 5:Load Error Warnings Info and Verbose
**/
  UINT8                       PcdSerialDebugLevel;

/** Offset 0x0A3A - Reserved
**/
  UINT8                       Reserved497;

/** Offset 0x0A3B - Reserved
**/
  UINT8                       Reserved498;

/** Offset 0x0A3C - Reserved
**/
  UINT16                      Reserved499;

/** Offset 0x0A3E - Reserved
**/
  UINT16                      Reserved500;

/** Offset 0x0A40 - Reserved
**/
  UINT8                       Reserved501;

/** Offset 0x0A41 - Reserved
**/
  UINT8                       Reserved502;

/** Offset 0x0A42 - TCSS USB Port Enable
  Bitmap for per port enabling
**/
  UINT8                       UsbTcPortEnPreMem;

/** Offset 0x0A43 - Reserved
**/
  UINT8                       Reserved503;

/** Offset 0x0A44 - Reserved
**/
  UINT16                      Reserved504;

/** Offset 0x0A46 - Reserved
**/
  UINT8                       Reserved505;

/** Offset 0x0A47 - Reserved
**/
  UINT8                       Reserved506;

/** Offset 0x0A48 - Reserved
**/
  UINT32                      Reserved507[4];

/** Offset 0x0A58 - Reserved
**/
  UINT16                      Reserved508;

/** Offset 0x0A5A - Reserved
**/
  UINT8                       Reserved509;

/** Offset 0x0A5B - Reserved
**/
  UINT8                       Reserved510;

/** Offset 0x0A5C - Reserved
**/
  UINT8                       Reserved511;

/** Offset 0x0A5D - Reserved
**/
  UINT8                       Reserved512;

/** Offset 0x0A5E - Reserved
**/
  UINT8                       Reserved513;

/** Offset 0x0A5F - Reserved
**/
  UINT8                       Reserved514;

/** Offset 0x0A60 - Reserved
**/
  UINT16                      Reserved515;

/** Offset 0x0A62 - Reserved
**/
  UINT16                      Reserved516;

/** Offset 0x0A64 - Reserved
**/
  UINT16                      Reserved517;

/** Offset 0x0A66 - Reserved
**/
  UINT8                       Reserved518;

/** Offset 0x0A67 - Reserved
**/
  UINT8                       Reserved519;

/** Offset 0x0A68 - Reserved
**/
  UINT8                       Reserved520;

/** Offset 0x0A69 - Reserved
**/
  UINT8                       Reserved521;

/** Offset 0x0A6A - Reserved
**/
  UINT8                       Reserved522;

/** Offset 0x0A6B - Reserved
**/
  UINT8                       Reserved523[4];

/** Offset 0x0A6F - Skip external display device scanning
  Enable: Do not scan for external display device, Disable (Default): Scan external
  display devices
  $EN_DIS
**/
  UINT8                       SkipExtGfxScan;

/** Offset 0x0A70 - Reserved
**/
  UINT8                       Reserved524;

/** Offset 0x0A71 - Lock PCU Thermal Management registers
  Lock PCU Thermal Management registers. Enable(Default)=1, Disable=0
  $EN_DIS
**/
  UINT8                       LockPTMregs;

/** Offset 0x0A72 - Reserved
**/
  UINT8                       Reserved525;

/** Offset 0x0A73 - Reserved
**/
  UINT8                       Reserved526;

/** Offset 0x0A74 - Reserved
**/
  UINT32                      Reserved527;

/** Offset 0x0A78 - Reserved
**/
  UINT8                       Reserved528;

/** Offset 0x0A79 - Reserved
**/
  UINT8                       Reserved529;

/** Offset 0x0A7A - Reserved
**/
  UINT16                      Reserved530;

/** Offset 0x0A7C - Reserved
**/
  UINT16                      Reserved531;

/** Offset 0x0A7E - Reserved
**/
  UINT8                       Reserved532[89];

/** Offset 0x0AD7 - Reserved
**/
  UINT8                       Reserved533;

/** Offset 0x0AD8 - Reserved
**/
  UINT16                      Reserved534;

/** Offset 0x0ADA - Reserved
**/
  UINT16                      Reserved535;

/** Offset 0x0ADC - Reserved
**/
  UINT8                       Reserved536[12];

/** Offset 0x0AE8 - Smbus dynamic power gating
  Disable or Enable Smbus dynamic power gating.
  $EN_DIS
**/
  UINT8                       SmbusDynamicPowerGating;

/** Offset 0x0AE9 - Disable and Lock Watch Dog Register
  Set 1 to clear WDT status, then disable and lock WDT registers.
  $EN_DIS
**/
  UINT8                       WdtDisableAndLock;

/** Offset 0x0AEA - Reserved
**/
  UINT8                       Reserved537;

/** Offset 0x0AEB - Reserved
**/
  UINT8                       Reserved538;

/** Offset 0x0AEC - Reserved
**/
  UINT8                       Reserved539;

/** Offset 0x0AED - Reserved
**/
  UINT8                       Reserved540;

/** Offset 0x0AEE - Reserved
**/
  UINT8                       Reserved541;

/** Offset 0x0AEF - Reserved
**/
  UINT8                       Reserved542;

/** Offset 0x0AF0 - Reserved
**/
  UINT8                       Reserved543;

/** Offset 0x0AF1 - Reserved
**/
  UINT8                       Reserved544;

/** Offset 0x0AF2 - Skip CPU replacement check
  Test, 0: disable, 1: enable, Setting this option to skip CPU replacement check
  $EN_DIS
**/
  UINT8                       SkipCpuReplacementCheck;

/** Offset 0x0AF3 - Reserved
**/
  UINT8                       Reserved545;

/** Offset 0x0AF4 - Reserved
**/
  UINT8                       Reserved546;

/** Offset 0x0AF5 - Serial Io Uart Debug Mode
  Select SerialIo Uart Controller mode
  0:SerialIoUartDisabled, 1:SerialIoUartPci, 2:SerialIoUartHidden, 3:SerialIoUartCom,
  4:SerialIoUartSkipInit
**/
  UINT8                       SerialIoUartDebugMode;

/** Offset 0x0AF6 - Reserved
**/
  UINT8                       Reserved547[2];

/** Offset 0x0AF8 - Reserved
**/
  UINT32                      Reserved548;

/** Offset 0x0AFC - Reserved
**/
  UINT32                      Reserved549;

/** Offset 0x0B00 - Reserved
**/
  UINT32                      Reserved550;

/** Offset 0x0B04 - Reserved
**/
  UINT32                      Reserved551;

/** Offset 0x0B08 - Reserved
**/
  UINT32                      Reserved552;

/** Offset 0x0B0C - Reserved
**/
  UINT8                       Reserved553[8];

/** Offset 0x0B14 - Reserved
**/
  UINT8                       Reserved554[7];

/** Offset 0x0B1B - Reserved
**/
  UINT8                       Reserved555[5];
} FSP_M_CONFIG;

/** Fsp M UPD Configuration
**/
typedef struct {

/** Offset 0x0000
**/
  FSP_UPD_HEADER              FspUpdHeader;

/** Offset 0x0020
**/
  FSPM_ARCH_UPD               FspmArchUpd;

/** Offset 0x0040
**/
  FSP_M_CONFIG                FspmConfig;

/** Offset 0x0B20
**/
  UINT8                       UnusedUpdSpace37[6];

/** Offset 0x0B26
**/
  UINT16                      UpdTerminator;
} FSPM_UPD;

#pragma pack()

#endif
